pub struct Aggregator {
pub num_keys: u32,
pub threshold: u32,
pub poly: Vec<Point>,
}Expand description
The group signature aggregator
Fields
num_keys: u32The total number of keys
threshold: u32The threshold of signing keys needed to construct a valid signature
poly: Vec<Point>The aggregate group polynomial; poly[0] is the group public key
Implementations
Sourceimpl Aggregator
impl Aggregator
Sourcepub fn sign_with_tweak(
&mut self,
msg: &[u8],
nonces: &[PublicNonce],
sig_shares: &[SignatureShare],
_key_ids: &[u32],
tweak: Option<Scalar>,
) -> Result<(Point, Signature), AggregatorError>
pub fn sign_with_tweak( &mut self, msg: &[u8], nonces: &[PublicNonce], sig_shares: &[SignatureShare], _key_ids: &[u32], tweak: Option<Scalar>, ) -> Result<(Point, Signature), AggregatorError>
Aggregate the party signatures using a tweak. The posible values for tweak are None - standard FROST signature Some(0) - BIP-340 schnorr signature using 32-byte private key adjustments Some(t) - BIP-340 schnorr signature with BIP-341 tweaked keys, using 32-byte private key adjustments
Check the party signatures after a failed group signature. The posible values for tweak are None - standard FROST signature Some(0) - BIP-340 schnorr signature using 32-byte private key adjustments Some(t) - BIP-340 schnorr signature with BIP-341 tweaked keys, using 32-byte private key adjustments