pub struct Party {
pub party_id: u32,
pub key_ids: Vec<u32>,
/* private fields */
}Expand description
A WSTS party, which encapsulates a single polynomial, nonce, and one private key per key ID
Fields
party_id: u32The party ID
key_ids: Vec<u32>The key IDs for this party
Implementations
Sourceimpl Party
impl Party
Sourcepub fn new<RNG: RngCore + CryptoRng>(
party_id: u32,
key_ids: &[u32],
num_parties: u32,
num_keys: u32,
threshold: u32,
rng: &mut RNG,
) -> Self
pub fn new<RNG: RngCore + CryptoRng>( party_id: u32, key_ids: &[u32], num_parties: u32, num_keys: u32, threshold: u32, rng: &mut RNG, ) -> Self
Construct a random Party with the passed party ID, key IDs, and parameters
Sourcepub fn gen_nonce<RNG: RngCore + CryptoRng>(
&mut self,
secret_key: &Scalar,
rng: &mut RNG,
) -> PublicNonce
pub fn gen_nonce<RNG: RngCore + CryptoRng>( &mut self, secret_key: &Scalar, rng: &mut RNG, ) -> PublicNonce
Generate and store a private nonce for a signing round
Sourcepub fn get_poly_commitment<RNG: RngCore + CryptoRng>(
&self,
ctx: &[u8],
rng: &mut RNG,
) -> Option<PolyCommitment>
pub fn get_poly_commitment<RNG: RngCore + CryptoRng>( &self, ctx: &[u8], rng: &mut RNG, ) -> Option<PolyCommitment>
Get a public commitment to the private polynomial
Get the shares of this party’s private polynomial for all keys
Sourcepub fn compute_secret(
&mut self,
private_shares: &HashMap<u32, HashMap<u32, Scalar>>,
public_shares: &HashMap<u32, PolyCommitment>,
ctx: &[u8],
) -> Result<(), DkgError>
pub fn compute_secret( &mut self, private_shares: &HashMap<u32, HashMap<u32, Scalar>>, public_shares: &HashMap<u32, PolyCommitment>, ctx: &[u8], ) -> Result<(), DkgError>
Compute this party’s share of the group secret key, but first check that the data is valid and consistent. This raises an issue though: what if we have private_shares and public_shares from different parties? To resolve the ambiguity, assume that the public_shares represent the correct group of parties.
Sourcepub fn sign(
&self,
msg: &[u8],
party_ids: &[u32],
key_ids: &[u32],
nonces: &[PublicNonce],
) -> SignatureShare
pub fn sign( &self, msg: &[u8], party_ids: &[u32], key_ids: &[u32], nonces: &[PublicNonce], ) -> SignatureShare
Sign msg with this party’s shares of the group private key, using the set of party_ids, key_ids and corresponding nonces
Sourcepub fn sign_with_tweak(
&self,
msg: &[u8],
party_ids: &[u32],
key_ids: &[u32],
nonces: &[PublicNonce],
tweak: Option<Scalar>,
) -> SignatureShare
pub fn sign_with_tweak( &self, msg: &[u8], party_ids: &[u32], key_ids: &[u32], nonces: &[PublicNonce], tweak: Option<Scalar>, ) -> SignatureShare
Sign msg with this party’s shares of the group private key, using the set of party_ids, key_ids and corresponding nonces with a tweaked public key. The posible values for tweak are
None - standard FROST signature
Some(0) - BIP-340 schnorr signature using 32-byte private key adjustments
Some(t) - BIP-340 schnorr signature with BIP-341 tweaked keys, using 32-byte private key adjustments